"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const await_to_js_1 = tslib_1.__importDefault(require("await-to-js"));
class FilterNonPullRequestPlugin {
    constructor() {
        this.name = 'Filter Non Pull Request';
    }
    apply(auto) {
        auto.hooks.onCreateLogParse.tap(this.name, logParse => {
            logParse.hooks.omitCommit.tapPromise(this.name, async (commit) => {
                // tslint:disable-next-line early-exit
                if (commit.pullRequest && commit.pullRequest.number) {
                    const { number: prNumber } = commit.pullRequest;
                    const [err, info] = await await_to_js_1.default(auto.git.getPr(prNumber));
                    // Omit PRs that don't exist on the repo
                    if (err && err.message.includes('Not Found')) {
                        return true;
                    }
                    if (err) {
                        throw err;
                    }
                    if (!info) {
                        throw new Error(`Could not find PR: ${prNumber}`);
                    }
                    // Omit issues
                    if (!info.data.pull_request) {
                        return true;
                    }
                }
            });
        });
    }
}
exports.default = FilterNonPullRequestPlugin;
//# sourceMappingURL=filter-non-pull-request.js.map