"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const parse_github_url_1 = tslib_1.__importDefault(require("parse-github-url"));
const util_1 = require("util");
const readFile = util_1.promisify(fs_1.default.readFile);
const getPackageConfig = async () => {
    const pkgConfig = await readFile('./package.json', 'utf-8');
    return JSON.parse(pkgConfig);
};
async function getConfigFromPackageJson() {
    const { repository } = await getPackageConfig();
    if (!repository) {
        throw new Error('Cannot read repo info from package.json');
    }
    const { owner, name } = parse_github_url_1.default(typeof repository === 'string' ? repository : repository.url) || {};
    if (!owner || !name) {
        throw new Error('Cannot read owner and package name from GitHub URL in package.json');
    }
    return {
        repo: name,
        owner
    };
}
exports.default = getConfigFromPackageJson;
//# sourceMappingURL=package-config.js.map