"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const env_ci_1 = tslib_1.__importDefault(require("env-ci"));
const path_1 = tslib_1.__importDefault(require("path"));
const registry_url_1 = tslib_1.__importDefault(require("registry-url"));
const url_join_1 = tslib_1.__importDefault(require("url-join"));
const user_home_1 = tslib_1.__importDefault(require("user-home"));
const utils_1 = require("./utils");
const { isCi } = env_ci_1.default();
async function setTokenOnCI(logger) {
    if (!isCi) {
        return;
    }
    const { publishConfig = {}, name } = await utils_1.loadPackageJson();
    const rc = path_1.default.join(user_home_1.default, '.npmrc');
    let contents = '';
    try {
        contents = (await utils_1.readFile(rc)).toString();
    }
    catch (error) {
        // No ~/.npmrc set up
    }
    let registry;
    if (publishConfig.registry) {
        registry = publishConfig.registry;
    }
    else if (name && name.startsWith('@')) {
        const scope = name.split(`/`)[0];
        registry = registry_url_1.default(scope);
    }
    else {
        registry = registry_url_1.default();
    }
    logger.verbose.note(`Using ${registry} registry for package`);
    const url = registry.replace(/^https?:/, ``);
    // eslint-disable-next-line no-template-curly-in-string
    const authTokenString = url_join_1.default(url, ':_authToken=${NPM_TOKEN}');
    logger.verbose.info(`Will set authentication token string in ${rc}`);
    if (contents.indexOf(authTokenString) !== -1) {
        logger.verbose.success(`npmrc file, ${rc}, is already setup correctly`);
        return;
    }
    logger.verbose.info(`Writing authentication token string, ${authTokenString}, to ${rc}`);
    await utils_1.writeFile(rc, `${contents}\n${authTokenString}`.trim());
    logger.log.success(`Wrote authentication token string to ${rc}`);
}
exports.default = setTokenOnCI;
//# sourceMappingURL=set-npm-token.js.map